@@ -2,6 +2,8 @@ import re
 from typing import Optional, Dict, List, Union
 import functools
 import numpy as np
+import itertools
+from .shingleseqs import shingleseqs_k
 
 
 def select_most_frequent_shingles(matches: List[str],
@@ -401,7 +403,7 @@ def sort_by_memostats(a, b):
 
 def shingles_to_patterns(memo: Dict[str, int],
                          wildcard: Optional[str] = '\uFFFF'
-                         ) -> list:  # List[re.Pattern]
+                         ):  # -> Dict[int, List[re.Pattern]]:
     """Convert shingles with wildcards to regex patterns
 
     Parameters:
@@ -420,7 +422,7 @@ def shingles_to_patterns(memo: Dict[str, int],
 
     Returns:
     --------
-    PATTERNS : List[re.Pattern]
+    PATTERNS : Dict[int, List[re.Pattern]]
         The regex.compile patterns based on the selected shingles in the
           memoization cache.
     """
@@ -436,16 +438,21 @@ def shingles_to_patterns(memo: Dict[str, int],
     MEMOSTATS.sort(key=sort_by_memostats)
     shingles = [x[0] for x in MEMOSTATS]
     # convert shingles to regex patterns
-    PATTERNS = []
+    PATTERNS = {}
     for shingle in shingles:
+        # create sublist
+        n = len(shingle)
+        if PATTERNS.get(n) is None:
+            PATTERNS[n] = []
+        # create regex
         reg = r"\w{1}".join([re.escape(s) for s in shingle.split(wildcard)])
         pat = re.compile(f"^{reg}$")
-        PATTERNS.append(pat)
+        PATTERNS[n].append(pat)
     return PATTERNS
 
 
 def encode_with_patterns(x: Union[list, str],
-                         PATTERNS: list,  # List[re.Pattern]
+                         PATTERNS: dict,  # Dict[int, List[re.Pattern]],
                          unkid: Optional[int] = None):
     """Encode all elements of x with the regex pattern.
 
@@ -455,7 +462,7 @@ def encode_with_patterns(x: Union[list, str],
         Encoding happens if type(x)==str. If type(x)=list then a recursive
           call on each list element is triggered.
 
-    PATTERNS : List[re.Pattern]
+    PATTERNS : Dict[int, List[re.Pattern]]
         The regex.compile patterns based on the selected shingles in the
           memoization cache.
 
@@ -468,10 +475,86 @@ def encode_with_patterns(x: Union[list, str],
         The IDs refer to the position index in PATTERNS list
     """
     if isinstance(x, str):
-        n_pat = len(PATTERNS)
+        nx = len(x)
+        n_pat = len(PATTERNS.get(nx, []))
         for i in range(n_pat):
-            if PATTERNS[i].match(x):
+            if PATTERNS[nx][i].match(x):
                 return i
         return unkid if unkid else n_pat
     else:
         return [encode_with_patterns(el, PATTERNS, unkid) for el in x]
+
+
+def encode_multi_match_str(x: str,
+                           PATTERNLIST: list,  # List[re.Pattern],
+                           offset: int,
+                           num_matches: Optional[int] = 1,
+                           unkid: Optional[int] = None):
+    """ Encode 1 shingle for `encode_multi_match_corpus` """
+    out = []
+    for i, pat in enumerate(PATTERNLIST):
+        if pat.match(x):
+            out.append(i + offset)
+            if len(out) >= num_matches:
+                break
+    # fill empty list elements
+    for _ in range(num_matches - len(out)):
+        out.append(unkid)
+    return out
+
+
+def encode_multi_match_corpus(corpus: List[str],
+                              k: int,
+                              PATTERNS: list,  # List[re.Pattern],
+                              num_matches: Optional[int] = 1,
+                              unkid: Optional[int] = None,
+                              stack: bool = True):
+    """ Shingle and encode corpus
+
+    Example:
+    --------
+    corpus = ["lenghty text.", "another long article"]
+    encoded, shingled = encode_multi_match_corpus(
+        corpus, k=k, PATTERNS=PATTERNS, num_matches=3, stack=True)
+    """
+    # generate all shingles (docs, k, seqlen)
+    shingled = [
+        shingleseqs_k(doc, k=k, padding='post', placeholder="[PAD]")
+        for doc in corpus]
+
+    # transpose (docs, seqlen, k)
+    shingled = [
+        np.array(shingled_doc, dtype=object).T.tolist()
+        for shingled_doc in shingled]
+
+    # lookup list for offsets, n=i+1
+    # e.g., [0, 80, 243, 508, 650]
+    offsets = np.cumsum([len(PATTERNS.get(i, [])) for i in range(k)]).tolist()
+
+    # encode (docs, seqlen, k)
+    encoded = []
+    for doc in shingled:
+        encdoc = []
+        for seqpos in doc:
+            encseqpos = []
+            for nkm1, ksegment in enumerate(seqpos):
+                encseqpos.append(encode_multi_match_str(
+                    ksegment,
+                    PATTERNLIST=PATTERNS.get(nkm1 + 1, []),
+                    offset=offsets[nkm1],
+                    num_matches=min(nkm1 + 1, num_matches),
+                    unkid=unkid))
+            encdoc.append(encseqpos)
+        encoded.append(encdoc)
+
+    # flatten (docs, seqlen, k, num) to (docs, seqlen, k*num)
+    encoded = [
+        [list(itertools.chain(*seqpos)) for seqpos in doc]
+        for doc in encoded]
+
+    # merge to one big sequence
+    if stack:
+        encoded = np.vstack(encoded)
+
+    # done
+    return encoded, shingled
